@@ -1,22 +1,21 @@
 import argparse
-import os
 import typing
+import pathlib
+
+import discord
 
 from .runner import run_bot, run_website
 
 
-def create_file(*path, content:str=None, throw_error:bool=False):
-    for index, i in enumerate(path[:-1]):
-        try:
-            os.mkdir(f"./{os.sep.join(path[:index + 1])}")
-        except FileExistsError:
-            pass
+def create_file(*path, content: str = None):
+    joined_folder_path = pathlib.Path("./").joinpath(*path[:-1])
+    joined_file_path = pathlib.Path("./").joinpath(*path)
+    joined_folder_path.mkdir(parents=True, exist_ok=True)
     try:
-        with open(f"./{os.sep.join(path)}", "x") as a:
+        with open(joined_file_path, "x") as a:
             a.write(content)
-    except FileExistsError as e:
-        if throw_error:
-            raise e
+    except FileExistsError:
+        print(f"File {joined_file_path} was not created as one already exists.")
 
 
 # Parse arguments
@@ -39,13 +38,14 @@ def get_default_program_arguments() -> argparse.ArgumentParser:
     # LOGLEVEL_CHOICES.extend([i.lower() for i in LOGLEVEL_CHOICES])
 
     # Set up our parsers and subparsers
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(prog="vbu")
     runner_subparser = parser.add_subparsers(dest="subcommand")
     runner_subparser.required = True
     bot_subparser = runner_subparser.add_parser("run-bot")
     website_subparser = runner_subparser.add_parser("run-website")
     create_config_subparser = runner_subparser.add_parser("create-config")
     check_config_subparser = runner_subparser.add_parser("check-config")
+    runner_subparser.add_parser("version")
 
     # Set up the bot arguments
     bot_subparser.add_argument("bot_directory", nargs="?", default=".", help="The directory containing a config and a cogs folder for the bot to run.")
@@ -72,7 +72,9 @@ def get_default_program_arguments() -> argparse.ArgumentParser:
     return parser
 
 
-def check_config_value(base_config_key:typing.List[str], base_config_value:typing.Any, compare_config_value:typing.Any) -> None:
+def check_config_value(
+        base_config_key: typing.List[str], base_config_value: typing.Any,
+        compare_config_value: typing.Any) -> None:
     """
     Recursively checks a config item to see if it's valid against a base config item
     """
@@ -101,6 +103,9 @@ def check_config_value(base_config_key:typing.List[str], base_config_value:typin
 
 
 def main():
+    """
+    The main method for running all of vbu.
+    """
 
     # Wew let's see if we want to run a bot
     parser = get_default_program_arguments()
@@ -111,60 +116,26 @@ def main():
         config_type = args.config_type[0]
         from . import config
         if config_type in ["website", "all"]:
-            website_frontend_file_content = (
-                "from aiohttp.web import HTTPFound, Request, Response, RouteTableDef\n"
-                "from voxelbotutils import web as webutils\n"
-                "import aiohttp_session\n"
-                "import discord\n"
-                "from aiohttp_jinja2 import template\n\n\n"
-                "routes = RouteTableDef()\n"
-            )
-            website_backend_file_content = website_frontend_file_content + (
-                "\n\n@routes.get('/login_processor')\n"
-                "async def login_processor(request:Request):\n"
-                '    """\n'
-                '    Page the discord login redirects the user to when successfully logged in with Discord.\n'
-                '    """\n\n'
-                "    v = await webutils.process_discord_login(request)\n"
-                "    if isinstance(v, Response):\n"
-                "        # return v\n"
-                "        return HTTPFound('/')\n"
-                "    session = await aiohttp_session.get_session(request)\n"
-                "    return HTTPFound(location=session.pop('redirect_on_login', '/'))\n"
-                "\n\n@routes.get('/logout')\n"
-                "async def logout(request:Request):\n"
-                '    """\n'
-                "    Destroy the user's login session.\n"
-                '    """\n\n'
-                "    session = await aiohttp_session.get_session(request)\n"
-                "    session.invalidate()\n"
-                "    return HTTPFound(location='/')\n"
-                "\n\n@routes.get('/login')\n"
-                "async def login(request:Request):\n"
-                '    """\n'
-                "    Direct the user to the bot's Oauth login page.\n"
-                '    """\n\n'
-                '    return HTTPFound(location=webutils.get_discord_login_url(request, "/login_processor"))\n'
-            ).replace("from aiohttp_jinja2 import template\n", "")
-            create_file("config", "website.toml", content=config.web_config_file.lstrip(), throw_error=True)
+            create_file("config", "website.toml", content=config.web_config_file.lstrip())
             create_file("config", "website.example.toml", content=config.web_config_file.lstrip())
             create_file("config", "database.pgsql", content=config.database_file.lstrip())
-            create_file("run_website.bat", content="py -m voxelbotutils run-website .\n")
-            create_file("run_website.sh", content="python3 -m voxelbotutils run-website .\n")
+            # create_file("run_website.bat", content="py -m voxelbotutils run-website .\n")
+            # create_file("run_website.sh", content="python3 -m voxelbotutils run-website .\n")
             create_file(".gitignore", content="__pycache__/\nconfig/config.toml\nconfig/website.toml\n")
             create_file("requirements.txt", content="voxelbotutils[web]\n")
-            create_file("website", "frontend.py", content=website_frontend_file_content)
-            create_file("website", "backend.py", content=website_backend_file_content)
+            create_file("website", "frontend.py", content=config.website_frontend_content.lstrip())
+            create_file("website", "backend.py", content=config.website_backend_content.lstrip())
             create_file("website", "static", ".gitkeep", content="\n")
             create_file("website", "templates", ".gitkeep", content="\n")
             print("Created website config file.")
         if config_type in ["bot", "all"]:
-            create_file("config", "config.toml", content=config.config_file.lstrip(), throw_error=True)
+            create_file("config", "config.toml", content=config.config_file.lstrip())
             create_file("config", "config.example.toml", content=config.config_file.lstrip())
             create_file("config", "database.pgsql", content=config.database_file.lstrip())
             create_file("cogs", "ping_command.py", content=config.cog_example.lstrip())
-            create_file("run_bot.bat", content="py -m voxelbotutils run-bot .\n")
-            create_file("run_bot.sh", content="python3 -m voxelbotutils run-bot .\n")
+            # create_file("run_bot.bat", content="py -m voxelbotutils run-bot .\n")
+            # create_file("run_bot.sh", content="python3 -m voxelbotutils run-bot .\n")
+            # create_file("run_bot.py", content=config.run_bot_python_file.lstrip())
             create_file(".gitignore", content="__pycache__/\nconfig/config.toml\nconfig/website.toml\n")
             create_file("requirements.txt", content="voxelbotutils\n")
             print("Created bot config file.")
@@ -179,6 +150,7 @@ def main():
             base_config_file_text = config.web_config_file.lstrip()
         elif config_type == "bot":
             base_config_file_text = config.config_file.lstrip()
+        # todo: what happens if the option given isn't web or bot?
         base_config_file = toml.loads(base_config_file_text)
         try:
             with open(args.config_file) as a:
@@ -190,6 +162,12 @@ def main():
             check_config_value([key], value, compare_config_file.get(key))
         exit(1)
 
+    # If we just want the version
+    elif args.subcommand == "version":
+        from . import __version__
+        print(f"VoxelBotUtils v{__version__}")
+        exit(1)
+
     # Run things
     elif args.subcommand == "run-bot":
         run_bot(args)
