@@ -9,31 +9,35 @@ from .. import __version__
 
 class BotStats(utils.Cog):
 
-    @commands.command(aliases=['git', 'code'], cls=utils.Command, add_slash_command=False)
+    @utils.command(aliases=['git', 'code'], add_slash_command=False)
     @utils.checks.is_config_set('command_data', 'github_link')
     @commands.bot_has_permissions(send_messages=True)
-    async def github(self, ctx:utils.Context):
+    async def github(self, ctx: utils.Context):
         """
         Sends the GitHub Repository link.
         """
 
         await ctx.send(f"<{self.bot.config['command_data']['github_link']}>", embeddify=False)
 
-    @commands.command(cls=utils.Command)
+    @utils.command()
     @commands.bot_has_permissions(send_messages=True)
-    @utils.checks.is_config_set('command_data', 'invite_command_permissions')
-    async def invite(self, ctx:utils.Context):
+    @utils.checks.is_config_set('oauth', 'enabled')
+    async def invite(self, ctx: utils.Context):
         """
         Gives you the bot's invite link.
         """
 
-        invite_permissions = {i: True for i in self.bot.config['command_data']['invite_command_permissions']}
-        await ctx.send(f"<{self.bot.get_invite_link(**invite_permissions)}>", embeddify=False)
+        oauth = self.bot.config['oauth'].copy()
+        permissions = discord.Permissions.none()
+        for i in oauth.pop('permissions', list()):
+            setattr(permissions, i, True)
+        oauth['permissions'] = permissions
+        await ctx.send(f"<{self.bot.get_invite_link(**oauth)}>", embeddify=False)
 
-    @commands.command(cls=utils.Command)
+    @utils.command()
     @commands.bot_has_permissions(send_messages=True)
     @utils.checks.is_config_set('command_data', 'vote_command_enabled')
-    async def vote(self, ctx:utils.Context):
+    async def vote(self, ctx: utils.Context):
         """
         Gives you a link to vote for the bot.
         """
@@ -48,10 +52,10 @@ class BotStats(utils.Cog):
             return await ctx.send("Despite being enabled, the vote command has no vote links to provide :/")
         return await ctx.send("\n".join(output_strings), embeddify=False)
 
-    @commands.command(cls=utils.Command, aliases=['status', 'botinfo'], add_slash_command=False)
+    @utils.command(aliases=['status', 'botinfo'], add_slash_command=False)
     @commands.bot_has_permissions(send_messages=True, embed_links=True)
     @utils.checks.is_config_set('command_data', 'stats_command_enabled')
-    async def stats(self, ctx:utils.Context):
+    async def stats(self, ctx: utils.Context):
         """
         Gives you the stats for the bot.
         """
@@ -66,10 +70,10 @@ class BotStats(utils.Cog):
         embed.add_field("Creator", f"{creator!s}\n{creator_id}")
         embed.add_field("Library", f"Discord.py {discord.__version__}")
         if self.bot.shard_count != len((self.bot.shard_ids or [0])):
-            embed.add_field("Approximate Guild Count", int((len(self.bot.guilds) / len(self.bot.shard_ids or [0])) * self.bot.shard_count))
+            embed.add_field("Approximate Guild Count", format(int((len(self.bot.guilds) / len(self.bot.shard_ids or [0])) * self.bot.shard_count), ","))
         else:
-            embed.add_field("Guild Count", len(self.bot.guilds))
-        embed.add_field("Shard Count", self.bot.shard_count or 1)
+            embed.add_field("Guild Count", format(len(self.bot.guilds), ","))
+        embed.add_field("Shard Count", format(self.bot.shard_count or 1, ","))
         embed.add_field("Average WS Latency", f"{(self.bot.latency * 1000):.2f}ms")
         embed.add_field("Coroutines", f"{len([i for i in asyncio.Task.all_tasks() if not i.done()])} running, {len(asyncio.Task.all_tasks())} total.")
 
@@ -119,6 +123,6 @@ class BotStats(utils.Cog):
         await ctx.send(embed=embed)
 
 
-def setup(bot:utils.Bot):
+def setup(bot: utils.Bot):
     x = BotStats(bot)
     bot.add_cog(x)
