@@ -14,11 +14,11 @@ class ErrorHandler(utils.Cog):
     COMMAND_ERROR_RESPONSES = (
         (
             utils.errors.MissingRequiredArgumentString,
-            lambda ctx, error: f"You're missing the `{error.param}` argument, which is required for this command - see `{ctx.clean_prefix}help {ctx.invoked_with}`."
+            lambda ctx, error: f"You're missing `{error.param}`, which is required for this command - see `{ctx.clean_prefix}help {' '.join(ctx.command.qualified_name.split(' ')[:-1] + [ctx.invoked_with])}`."
         ),
         (
             commands.MissingRequiredArgument,
-            lambda ctx, error: f"You're missing the `{error.param.name}` argument, which is required for this command - see `{ctx.clean_prefix}help {ctx.invoked_with}`."
+            lambda ctx, error: f"You're missing `{error.param.name}`, which is required for this command - see `{ctx.clean_prefix}help {' '.join(ctx.command.qualified_name.split(' ')[:-1] + [ctx.invoked_with])}`."
         ),
         (
             (commands.UnexpectedQuoteError, commands.InvalidEndOfQuotedStringError, commands.ExpectedClosingQuoteError),
@@ -38,7 +38,11 @@ class ErrorHandler(utils.Cog):
         ),
         (
             commands.NSFWChannelRequired,
-            lambda ctx, error: "This command can't be run in a non-NSFW channel."
+            lambda ctx, error: f"You can only run this command in channels set as NSFW. {'You can set channels as NSFW in their channel settings.' if ctx.channel.permissions_for(ctx.author).manage_channels else ''}"
+        ),
+        (
+            utils.errors.BotNotInGuild,
+            lambda ctx, error: "The bot needs to be in the guild for you to run this command."
         ),
         (
             utils.errors.IsSlashCommand,
@@ -138,19 +142,23 @@ class ErrorHandler(utils.Cog):
         ),
         (
             commands.BadArgument,
-            lambda ctx, error: str(error)
+            lambda ctx, error: str(error).format(ctx=ctx, error=error)
+        ),
+        (
+            commands.ConversionError,
+            lambda ctx, error: "I failed to convert that argument - please try again in a few minutes."
         ),
         (
             commands.TooManyArguments,
-            lambda ctx, error: f"You gave too many arguments to this command - see `{ctx.clean_prefix}help {ctx.invoked_with}`."
+            lambda ctx, error: f"You gave too many arguments to this command - see `{ctx.clean_prefix}help {' '.join(ctx.command.qualified_name.split(' ')[:-1] + [ctx.invoked_with])}`."
         ),
         (
             discord.NotFound,
-            lambda ctx, error: None
+            lambda ctx, error: str(error).format(ctx=ctx, error=error)
         ),
         (
             commands.CheckFailure,
-            lambda ctx, error: str(error)
+            lambda ctx, error: str(error).format(ctx=ctx, error=error)
         ),
         (
             discord.Forbidden,
@@ -158,7 +166,7 @@ class ErrorHandler(utils.Cog):
         ),
         (
             (discord.HTTPException, aiohttp.ClientOSError),
-            lambda ctx, error: f"Discord messed up there somewhere - do you mind trying again? I received a {error.status} error."
+            lambda ctx, error: "Either I or Discord messed up running this command. Please try again later."
         ),
 
         # Disabled because they're base classes for the subclasses above
@@ -183,17 +191,26 @@ class ErrorHandler(utils.Cog):
         # (commands.CommandRegistrationError, lambda ctx, error: ""),
     )
 
-    async def send_to_ctx_or_author(self, ctx:utils.Context, text:str, author_text:str=None) -> typing.Optional[discord.Message]:
+    async def send_to_ctx_or_author(self, ctx: utils.Context, text: str, author_text: str = None) -> typing.Optional[discord.Message]:
         """
         Tries to send the given text to ctx, but failing that, tries to send it to the author
         instead. If it fails that too, it just stays silent.
         """
 
+        ephemeral = ctx.IS_INTERACTION and self.bot.config.get("ephemeral_error_messages", True)
         try:
-            return await ctx.send(text, allowed_mentions=discord.AllowedMentions(users=False, roles=False, everyone=False))
+            return await ctx.send(
+                text,
+                allowed_mentions=discord.AllowedMentions.none(),
+                ephemeral=ephemeral,
+            )
         except discord.Forbidden:
             try:
-                return await ctx.author.send(author_text or text, allowed_mentions=discord.AllowedMentions(users=False, roles=False, everyone=False))
+                return await ctx.author.send(
+                    author_text or text,
+                    allowed_mentions=discord.AllowedMentions.none(),
+                    ephemeral=ephemeral,
+                )
             except discord.Forbidden:
                 pass
         except discord.NotFound:
@@ -201,7 +218,7 @@ class ErrorHandler(utils.Cog):
         return None
 
     @utils.Cog.listener()
-    async def on_command_error(self, ctx:utils.Context, error:commands.CommandError):
+    async def on_command_error(self, ctx: utils.Context, error: commands.CommandError):
         """
         Global error handler for all the commands around wew.
         """
@@ -219,7 +236,8 @@ class ErrorHandler(utils.Cog):
         # Set up some errors that the owners are able to bypass
         owner_reinvoke_errors = (
             commands.MissingRole, commands.MissingAnyRole, commands.MissingPermissions,
-            commands.CommandOnCooldown, commands.DisabledCommand,
+            commands.CommandOnCooldown, commands.DisabledCommand, commands.CheckFailure,
+            utils.errors.IsNotUpgradeChatSubscriber, utils.errors.IsNotVoter, utils.errors.NotBotSupport,
         )
         if isinstance(error, owner_reinvoke_errors) and ctx.original_author_id in self.bot.owner_ids:
             return await ctx.reinvoke()
@@ -231,8 +249,10 @@ class ErrorHandler(utils.Cog):
 
         # See if it's in our list of common outputs
         output = None
+        error_found = False
         for error_types, function in self.COMMAND_ERROR_RESPONSES:
             if isinstance(error, error_types):
+                error_found = True
                 output = function(ctx, error)
                 break
 
@@ -248,9 +268,13 @@ class ErrorHandler(utils.Cog):
                 output = (output,)
             return await self.send_to_ctx_or_author(ctx, *output)
 
+        # Make sure not to send an error if it's "handled"
+        if error_found:
+            return
+
         # The output isn't a common output -- send them a plain error response
         try:
-            await ctx.send(f"`{str(error).strip()}`")
+            await ctx.send(f"`{str(error).strip()}`", allowed_mentions=discord.AllowedMentions.none())
         except (discord.Forbidden, discord.NotFound):
             pass
 
@@ -276,7 +300,13 @@ class ErrorHandler(utils.Cog):
             file_handle.seek(0)
             try:
                 file = discord.File(file_handle, filename="error_log.py")
-                await event_webhook.send(error_text, file=file, username=f"{self.bot.user.name} - Error", avatar_url=avatar_url)
+                await event_webhook.send(
+                    error_text,
+                    file=file,
+                    username=f"{self.bot.user.name} - Error",
+                    avatar_url=avatar_url,
+                    allowed_mentions=discord.AllowedMentions.none(),
+                )
             except discord.HTTPException as e:
                 self.logger.error(f"Failed to send webhook for event unhandled_error - {e}")
 
@@ -286,6 +316,6 @@ class ErrorHandler(utils.Cog):
             logger.error(line)
 
 
-def setup(bot:utils.Bot):
+def setup(bot: utils.Bot):
     x = ErrorHandler(bot)
     bot.add_cog(x)
