@@ -21,15 +21,79 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
     Handles commands that only the owner should be able to run.
     """
 
-    @commands.command(aliases=['src'], cls=utils.Command)
+    def __init__(self, bot: utils.Bot):
+        super().__init__(bot)
+        if bot.config.get("redis", {}).get("enabled"):
+            self.redis_ev_listener.start()
+
+    def cog_unload(self):
+        if bot.config.get("redis", {}).get("enabled"):
+            self.redis_ev_listener.stop()
+
+    @utils.redis_channel_handler("RunRedisEval")
+    async def redis_ev_listener(self, payload):
+        """
+        Listens for the redis* commands being run and invokes them.
+        """
+
+        # Get the info
+        channel_id = payload['channel_id']
+        message_id = payload['message_id']
+        guild_id = payload['guild_id']
+        author_id = payload['author_id']
+        channel: discord.TextChannel = await self.bot.fetch_channel(channel_id)
+        guild: discord.Guild = await self.bot.fetch_guild(guild_id)
+        channel.guild = guild
+        author: discord.Member = await guild.fetch_member(author_id)
+        bot: discord.Member = await guild.fetch_member(self.bot.user.id)
+        guild._add_member(bot)
+        message: discord.Message = await channel.fetch_message(message_id)
+        message.author = author
+
+        # Fix up the content
+        new_content = f"<@{self.bot.user.id}> {payload['content']}"
+        message.content = new_content
+
+        # And process
+        ctx: utils.Context = await self.bot.get_context(message)
+        ctx.message = message
+        ctx.guild = guild
+        ctx.channel = channel
+        ctx.author = author
+        ctx.me = bot
+        await self.bot.invoke(ctx)
+
+    @utils.command()
+    @commands.is_owner()
+    @utils.checks.is_config_set("redis", "enabled")
+    @commands.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
+    async def redis(self, ctx: utils.Context, *, content: str):
+        """
+        Pings a command to be run over redis.
+        """
+
+        if not content:
+            raise utils.errors.MissingRequiredArgumentString("content")
+        async with self.bot.redis() as re:
+            await re.publish("RunRedisEval", {
+                'channel_id': ctx.channel.id,
+                'message_id': ctx.message.id,
+                'guild_id': ctx.guild.id,
+                'author_id': ctx.author.id,
+                'content': content,
+            })
+
+    @utils.command(aliases=['src'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
-    async def source(self, ctx:utils.Context, *, command_name:str):
+    async def source(self, ctx: utils.Context, *, command_name: str):
         """
         Shows you the source for a given command.
         """
 
         # Get command
+        if not command_name:
+            raise utils.errors.MissingRequiredArgumentString("command_name")
         command = self.bot.get_command(command_name)
         if command is None:
             return await ctx.send(f"I couldn't find a command named `{command_name}`.", allowed_mentions=discord.AllowedMentions.none())
@@ -53,10 +117,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         # Paginate
         await utils.Paginator(pages, per_page=1).start(ctx)
 
-    @commands.command(aliases=['pm', 'dm', 'send'], cls=utils.Command)
+    @utils.command(aliases=['pm', 'dm', 'send'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True, add_reactions=True)
-    async def message(self, ctx:utils.Context, snowflake:int, *, content:str=None):
+    async def message(self, ctx: utils.Context, snowflake: int, *, content: str = None):
         """
         DMs a user the given content.
         """
@@ -129,20 +193,23 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         precision = "seconds"
         prefixes = ["milli", "micro", "nano", "pico"]
         index = 1
-        while float(format(time_taken, ",.3f")) < 10:
+        while float(format(time_taken, ".3f")) < 10:
             time_taken *= 1_000
             precision = f"{prefixes[index]}seconds"
             index += 1
-        return f"Executed in **{time_taken:.3f}** {precision}."
+        return f"Executed in **{time_taken:,.3f}** {precision}."
 
-    @commands.command(aliases=['evall', 'eval'], cls=utils.Command)
+    @utils.command(aliases=['evall', 'eval'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def ev(self, ctx:utils.Context, *, content:str):
+    async def ev(self, ctx: utils.Context, *, content: str = None):
         """
         Evaluates some Python code.
         """
 
+        if not content:
+            raise utils.errors.MissingRequiredArgumentString("content")
+
         # Make the environment
         env = {
             'bot': self.bot,
@@ -165,6 +232,8 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
 
         # Make code and output string
         content = self._cleanup_code(content)
+        if not content:
+            raise utils.errors.MissingRequiredArgumentString("content")
         code = f'async def func():\n{textwrap.indent(content, "  ")}'
 
         # Make the function into existence
@@ -208,6 +277,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         result = str(result_raw)  # The result as a string
         if result_raw is None:
             return
+        filetype = "py"
         text = f'```py\n{result}\n```'
         if type(result_raw) == dict:
             try:
@@ -215,32 +285,35 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
             except Exception:
                 pass
             else:
+                filetype = "json"
                 text = f'```json\n{result}\n```'
         text += self.get_execution_time(end_time, start_time)
 
         # Output to chat
         if len(text) > 2000:
             try:
-                return await ctx.send(self.get_execution_time(end_time, start_time), file=discord.File(io.StringIO(result), filename='ev.txt'))
+                return await ctx.send(self.get_execution_time(end_time, start_time), file=discord.File(io.StringIO(result), filename=f"ev.{filetype}"))
             except discord.HTTPException:
                 return await ctx.send("I don't have permission to attach files here.", embeddify=False)
         else:
             return await ctx.send(text, embeddify=False)
 
-    @commands.command(aliases=['rld', 'rl'], cls=utils.Command)
+    @utils.command(aliases=['rld', 'rl'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def reload(self, ctx:utils.Context, *cog_name:str):
+    async def reload(self, ctx: utils.Context, *cog_name: str):
         """
         Unloads and reloads a cog from the bot.
         """
 
         # Get a list of cogs to reload
-        cog_name = 'cogs.' + '_'.join([i for i in cog_name])
-        if cog_name == 'cogs.*':
+        cog_name = '_'.join([i for i in cog_name])
+        if cog_name == '*':
             cog_list = [i for i in self.bot.get_extensions() if i.startswith('cogs.')]
-        else:
+        elif '.' in cog_name:
             cog_list = [cog_name]
+        else:
+            cog_list = ['cogs.' + cog_name]
 
         # Reload our cogs
         reloaded_cogs = []
@@ -258,20 +331,22 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
                 await ctx.send(f"Error loading cog `{cog}`: ```py\n{traceback.format_exc()}```")
 
         # Output which cogs have been reloaded
-        if len(cog_list) == 1:
-            await ctx.send(f"Reloaded: `{cog_list[0]}`")
-        else:
-            await ctx.send("Reloaded:\n`" + "`\n`".join(cog_list) + "`")
+        if len(reloaded_cogs) == 1:
+            await ctx.send(f"Reloaded: `{reloaded_cogs[0]}`")
+        elif reloaded_cogs:
+            await ctx.send("Reloaded:\n`" + "`\n`".join(reloaded_cogs) + "`")
         return
 
-    @commands.command(cls=utils.Command, aliases=['downloadcog', 'dlcog', 'download', 'dl', 'stealcog'])
+    @utils.command(aliases=['downloadcog', 'dlcog', 'download', 'dl', 'stealcog'])
     @commands.is_owner()
-    async def downloadfile(self, ctx:utils.Context, url:str, file_folder:typing.Optional[str]):
-        """Download a cog from github"""
+    async def downloadfile(self, ctx: utils.Context, url: str, file_folder: typing.Optional[str]):
+        """
+        Download a cog from Github.
+        """
 
         # Convert github link to a raw link and grab contents
         raw_url = url.replace("/blob", "").replace("github.com", "raw.githubusercontent.com")
-        headers = {"User-Agent": f"Discord Bot - {self.bot.user}"}
+        headers = {"User-Agent": self.bot.user_agent}
         async with self.bot.session.get(raw_url, headers=headers) as r:
             text = await r.text()
 
@@ -313,10 +388,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         # And done
         await ctx.send(f"Downloaded the `{file_name}` cog, saved as `{file_path}`, and loaded successfully into the bot.")
 
-    @commands.command(cls=utils.Command)
+    @utils.command()
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def runsql(self, ctx:utils.Context, *, sql:str):
+    async def runsql(self, ctx: utils.Context, *, sql: str):
         """
         Runs a line of SQL into the database.
         """
@@ -364,20 +439,20 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
             file = discord.File(io.StringIO(string_output), filename="runsql.txt")
             await ctx.send(file=file)
 
-    @commands.group(cls=utils.Group)
+    @utils.group()
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def botuser(self, ctx:utils.Context):
+    async def botuser(self, ctx: utils.Context):
         """
         A parent command for the bot user configuration section.
         """
 
         pass
 
-    @botuser.command(name='name', aliases=['username'], cls=utils.Command)
+    @botuser.command(name='name', aliases=['username'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def botuser_name(self, ctx:utils.Context, *, username:str):
+    async def botuser_name(self, ctx: utils.Context, *, username: str):
         """
         Lets you set the username for the bot account.
         """
@@ -387,10 +462,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         await self.bot.user.edit(username=username)
         await ctx.send('Done.')
 
-    @botuser.command(name='avatar', aliases=['photo', 'image', 'picture'], cls=utils.Command)
+    @botuser.command(name='avatar', aliases=['photo', 'image', 'picture'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def botuser_avatar(self, ctx:utils.Context, *, image_url:typing.Optional[str]):
+    async def botuser_avatar(self, ctx: utils.Context, *, image_url: typing.Optional[str]):
         """
         Lets you set the profile picture of the bot.
         """
@@ -406,10 +481,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         await self.bot.user.edit(avatar=image_content)
         await ctx.send('Done.')
 
-    @botuser.command(name='activity', aliases=['game'], cls=utils.Command)
+    @botuser.command(name='activity', aliases=['game'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def botuser_activity(self, ctx:utils.Context, activity_type:str, *, name:typing.Optional[str]):
+    async def botuser_activity(self, ctx: utils.Context, activity_type: str, *, name: typing.Optional[str]):
         """
         Changes the activity of the bot.
         """
@@ -420,10 +495,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
             return await self.bot.set_default_presence()
         await self.bot.change_presence(activity=activity, status=self.bot.guilds[0].me.status)
 
-    @botuser.command(name='status', cls=utils.Command)
+    @botuser.command(name='status')
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def botuser_status(self, ctx:utils.Context, status:str):
+    async def botuser_status(self, ctx: utils.Context, status: str):
         """
         Changes the online status of the bot.
         """
@@ -431,10 +506,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         status = getattr(discord.Status, status.lower())
         await self.bot.change_presence(activity=self.bot.guilds[0].me.activity, status=status)
 
-    @commands.command(cls=utils.Command, aliases=['sudo'])
+    @utils.command(aliases=['sudo'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def su(self, ctx, who:discord.User, *, command:str):
+    async def su(self, ctx, who: discord.User, *, command: str):
         """
         Run a command as another user.
         """
@@ -456,10 +531,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         # Invoke it dab
         await self.bot.invoke(new_ctx)
 
-    @commands.command(cls=utils.Command, aliases=['sh'])
+    @utils.command(aliases=['sh'])
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def shell(self, ctx, *, command:str):
+    async def shell(self, ctx: utils.Context, *, command: str):
         """
         Run a shell command.
         """
@@ -498,19 +573,19 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         except discord.HTTPException:
             pass
 
-    @commands.group(cls=utils.Group)
+    @utils.group()
     @commands.is_owner()
-    async def export(self, ctx:utils.Context):
+    async def export(self, ctx: utils.Context):
         """
         The parent group for the export commands.
         """
 
         pass
 
-    @export.command(cls=utils.Command, name="commands")
+    @export.command(name="commands")
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @commands.is_owner()
-    async def export_commands(self, ctx:utils.Context):
+    async def export_commands(self, ctx: utils.Context):
         """
         Exports the commands for the bot as a markdown file.
         """
@@ -542,11 +617,11 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         # Output file
         await ctx.send(file=discord.File(io.StringIO('\n'.join(lines)), filename="commands.md"))
 
-    @export.command(cls=utils.Command, name="guild")
+    @export.command(name="guild")
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @utils.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
-    async def export_guild(self, ctx:utils.Context, guild_id:typing.Optional[int]):
+    async def export_guild(self, ctx: utils.Context, guild_id: typing.Optional[int]):
         """
         Exports data for a given guild from the database.
 
@@ -630,11 +705,11 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         file = discord.File(io.StringIO(file_content), filename=f"_db_migrate_{guild_id or ctx.guild.id}.py")
         await ctx.send(file=file)
 
-    @export.command(cls=utils.Command, name="table")
+    @export.command(name="table")
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @utils.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
-    async def export_table(self, ctx:utils.Context, table_name:str):
+    async def export_table(self, ctx: utils.Context, table_name: str):
         """
         Exports a given table from the database into a .csv file.
         """
@@ -670,6 +745,6 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
             return
 
 
-def setup(bot:utils.Bot):
+def setup(bot: utils.Bot):
     x = OwnerOnly(bot)
     bot.add_cog(x)
