@@ -8,18 +8,23 @@ from . import utils
 
 class BotSettings(utils.Cog):
 
-    @commands.command(cls=utils.Command, add_slash_command=False)
+    @utils.command(add_slash_command=False)
     @commands.bot_has_permissions(send_messages=True)
     @commands.guild_only()
     @utils.checks.is_config_set('database', 'enabled')
-    async def prefix(self, ctx:utils.Context, *, new_prefix:str=None):
+    async def prefix(self, ctx: utils.Context, *, new_prefix: str = None):
         """
         Changes the prefix that the bot uses.
         """
 
         # See if the prefix was actually specified
+        prefix_column = self.bot.config.get('guild_settings_prefix_column', 'prefix')
         if new_prefix is None:
-            return await ctx.send(f"The current prefix is `{self.bot.guild_settings[ctx.guild.id][prefix_column]}`.")
+            current_prefix = self.bot.guild_settings[ctx.guild.id][prefix_column] or self.bot.config['default_prefix']
+            return await ctx.send(
+                f"The current prefix is `{current_prefix}`.",
+                allowed_mentions=discord.AllowedMentions.none(),
+            )
 
         # See if the user has permission
         try:
@@ -32,7 +37,6 @@ class BotSettings(utils.Cog):
             return await ctx.send("The maximum length a prefix can be is 30 characters.")
 
         # Store setting
-        prefix_column = self.bot.config.get('guild_settings_prefix_column', 'prefix')
         self.bot.guild_settings[ctx.guild.id][prefix_column] = new_prefix
         async with self.bot.database() as db:
             await db(
@@ -40,9 +44,12 @@ class BotSettings(utils.Cog):
                 ON CONFLICT (guild_id) DO UPDATE SET {prefix_column}=excluded.prefix""".format(prefix_column=prefix_column),
                 ctx.guild.id, new_prefix
             )
-        await ctx.send(f"My prefix has been updated to `{new_prefix}`.")
+        await ctx.send(
+            f"My prefix has been updated to `{new_prefix}`.",
+            allowed_mentions=discord.AllowedMentions.none(),
+        )
 
-    @commands.command(cls=utils.Command, aliases=['follow'], add_slash_command=False)
+    @utils.command(aliases=['follow'], add_slash_command=False)
     @commands.has_permissions(manage_guild=True, manage_channels=True)
     @commands.bot_has_permissions(send_messages=True, add_reactions=True, manage_channels=True)
     @commands.guild_only()
@@ -68,7 +75,7 @@ class BotSettings(utils.Cog):
 
         # Cancel follow
         if str(reaction) == "\N{THUMBS DOWN SIGN}":
-            return await ctx.send("Alright, cancelling!", ignore_error=True)
+            return await ctx.send("Alright, cancelling!")
 
         # Get channel
         channel_id = self.bot.config['command_data']['updates_channel_id']
@@ -86,16 +93,17 @@ class BotSettings(utils.Cog):
 
         # Output message
         try:
-            await self.bot.wait_for("message", check=lambda m: m.content == f"{channel.guild.name} #{channel.name}", timeout=5)
+            check = lambda m: m.guild and m.guild.id == ctx.guild.id and m.content.endswith(f"#{channel.name}")
+            await self.bot.wait_for("message", check=check, timeout=5)
         except asyncio.TimeoutError:
             pass
         try:
             await m.delete()
         except discord.HTTPException:
             pass
-        return await ctx.send("Now following the bot's updates channel!", ignore_error=True)
+        return await ctx.send("Now following the bot's updates channel!")
 
 
-def setup(bot:utils.Bot):
+def setup(bot: utils.Bot):
     x = BotSettings(bot)
     bot.add_cog(x)
