@@ -3,7 +3,10 @@ import discord
 
 
 class NotBotSupport(commands.MissingRole):
-    """The generic error for the bot failing the :func:`voxelbotutils.checks.is_bot_support` check"""
+    """
+    The generic error for the bot failing the :func:`voxelbotutils.checks.is_bot_support` check -
+    is a subclass of :class:`discord.ext.commands.MissingRole`.
+    """
 
     def __init__(self):
         super().__init__("Bot Support Team")
@@ -19,17 +22,19 @@ def is_bot_support():
         NotBotSupport: If the given user isn't a member of the bot's support team.
     """
 
-    async def predicate(ctx:commands.Context):
+    async def predicate(ctx: commands.Context):
         if ctx.author.id in ctx.bot.owner_ids:
             return True
-        supportguild = await ctx.bot.fetch_support_guild() or ctx.guild
-        if supportguild is None:
+        support_guild = await ctx.bot.fetch_support_guild()
+        if support_guild is None:
             raise commands.NoPrivateMessage()
         try:
-            member = supportguild.get_member(ctx.author.id) or await supportguild.fetch_member(ctx.author.id)
-        except discord.HTTPException:
-            return NotBotSupport()
-        if ctx.bot.config.get("bot_support_role_id", 0) in member._roles or ctx.author.id in ctx.bot.owner_ids:
+            member = support_guild.get_member(ctx.author.id) or await support_guild.fetch_member(ctx.author.id)
+            if member is None:
+                raise AttributeError()
+        except (discord.HTTPException, AttributeError):
+            raise NotBotSupport()
+        if ctx.bot.config.get("bot_support_role_id", None) in [i.id for i in member.roles] or ctx.author.id in ctx.bot.owner_ids:
             return True
         raise NotBotSupport()
     return commands.check(predicate)
