@@ -1,6 +1,6 @@
 from discord.ext import commands
 
-from ..interactions import InteractionContext
+# from ..interactions import InteractionContext
 
 
 class IsSlashCommand(commands.DisabledCommand):
@@ -11,6 +11,10 @@ class IsNotSlashCommand(commands.DisabledCommand):
     """Raised when a given command failes the :func:`voxelbotutils.checks.is_slash_command` check."""
 
 
+class BotNotInGuild(commands.DisabledCommand):
+    """Raised when a given command failes the :func:`voxelbotutils.checks.bot_in_guild` check."""
+
+
 def is_slash_command():
     """
     Checks that the command has been invoked from a slash command.
@@ -20,8 +24,7 @@ def is_slash_command():
     """
 
     async def predicate(ctx):
-        v = isinstance(ctx, InteractionContext)
-        if v:
+        if ctx.IS_INTERACTION:
             return True
         raise IsNotSlashCommand()
     return commands.check(predicate)
@@ -36,8 +39,22 @@ def is_not_slash_command():
     """
 
     async def predicate(ctx):
-        v = isinstance(ctx, InteractionContext)
-        if not v:
+        if not ctx.IS_INTERACTION:
             return True
         raise IsSlashCommand()
     return commands.check(predicate)
+
+
+def bot_in_guild():
+    """
+    Checks that the bot is in the guild where this command is being called.
+
+    Raises:
+        BotNotInGuild: If the bot isn't in the guild where the command is being called.
+    """
+
+    async def predicate(ctx):
+        if ctx.bot.get_guild(ctx.guild.id) is None:
+            raise BotNotInGuild()
+        return True
+    return commands.check(predicate)
