@@ -1,10 +1,9 @@
-# flake8: noqa
 from .checks.is_config_set import ConfigNotSet
 from .checks.meta_command import InvokedMetaCommand
 from .checks.bot_is_ready import BotNotReady
 from .checks.is_voter import IsNotVoter
 from .checks.is_bot_support import NotBotSupport
-from .checks.slash_commands import IsSlashCommand, IsNotSlashCommand
-from .checks.is_upgrade_chat_subscriber import IsNotUpgradeChatSubscriber
+from .checks.slash_commands import IsSlashCommand, IsNotSlashCommand, BotNotInGuild
+from .checks.is_upgrade_chat_subscriber import IsNotUpgradeChatSubscriber, IsNotUpgradeChatPurchaser
 from .missing_required_argument import MissingRequiredArgumentString
 from .time_value import InvalidTimeDuration
