@@ -9,7 +9,23 @@ import aioredlock
 
 class RedisConnection(object):
     """
-    A wrapper for an :class:`aioredis.Redis` object.
+    A wrapper for an :class:`aioredis.Redis` object, provided in your bot object
+    at :attr:`Bot.redis` for your convenience. Implemented are setter and getter methods
+    for the redis database, as well as publish and subscribe via a decorator.
+
+    Examples:
+
+        ::
+
+            # In a command
+            async with bot.redis() as re:
+                await re.publish("channel_name", {"foo": "bar"})
+                await re.publish_str("channel_two", "baz")
+
+            # In a cog
+            @voxelbotutils.redis_channel_handler("channel_name")
+            async def handler(self, payload):
+                self.logger.info(payload)
     """
 
     config: dict = None
@@ -17,13 +33,13 @@ class RedisConnection(object):
     logger: logging.Logger = None  # Set as a child of bot.logger
     lock_manager: aioredlock.Aioredlock = None
 
-    def __init__(self, connection:aioredis.RedisConnection=None):
+    def __init__(self, connection: aioredis.RedisConnection=None):
         """:meta private:"""
 
         self.conn = connection
 
     @classmethod
-    async def create_pool(cls, config:dict) -> None:
+    async def create_pool(cls, config: dict) -> None:
         """
         Creates and connects the pool object.
 
@@ -60,10 +76,10 @@ class RedisConnection(object):
         self.conn = v.conn
         return self
 
-    async def __aexit__(self, exc_type, exc, tb):
+    async def __aexit__(self, *args, **kwargs):
         await self.disconnect()
 
-    async def publish(self, channel:str, json:dict) -> None:
+    async def publish(self, channel: str, json: dict) -> None:
         """
         Publishes some JSON to a given redis channel.
 
@@ -75,7 +91,7 @@ class RedisConnection(object):
         self.logger.debug(f"Publishing JSON to channel {channel}: {json!s}")
         return await self.conn.publish_json(channel, json)
 
-    async def publish_str(self, channel:str, message:str) -> None:
+    async def publish_str(self, channel: str, message: str) -> None:
         """
         Publishes a message to a given redis channel.
 
@@ -87,7 +103,7 @@ class RedisConnection(object):
         self.logger.debug(f"Publishing message to channel {channel}: {message}")
         return await self.conn.publish(channel, message)
 
-    async def set(self, key:str, value:str) -> None:
+    async def set(self, key: str, value: str) -> None:
         """
         Sets a key/value pair in the redis DB.
 
@@ -99,9 +115,9 @@ class RedisConnection(object):
         self.logger.debug(f"Setting Redis key:value pair with {key}:{value}")
         return await self.conn.set(key, value)
 
-    async def get(self, key:str) -> str:
+    async def get(self, key: str) -> str:
         """
-        Grabs a value from the Redis DB given a key.
+        Gets a value from the Redis DB given a key.
 
         Args:
             key (str): The key that you want to get from the Redis database.
@@ -118,10 +134,10 @@ class RedisConnection(object):
 
     async def mget(self, *keys) -> typing.List[str]:
         """
-        Grabs a value from the redis DB given a key.
+        Gets multiple values from the Redis DB given a list of keys.
 
         Args:
-            key (str): The keys that you want to get from the database.
+            keys (str): The keys that you want to get from the database.
 
         Returns:
             typing.List[str]: The values from the Redis database associated with the given keys.
@@ -192,9 +208,9 @@ class RedisChannelHandler(object):
                 if asyncio.iscoroutine(self.callback) or asyncio.iscoroutinefunction(self.callback):
                     asyncio.create_task(self.callback(self.cog, data))
                 else:
-                    self.callback(data)
+                    self.callback(self.cog, data)
             except Exception as e:
-                self.logger.error(e)
+                self.connection.logger.error(e)
 
     async def unsubscribe(self):
         """
