@@ -16,8 +16,9 @@ class SettingsMenuConverter(object):
     __slots__ = ('prompt', 'asking_for', 'converter', 'emojis', 'serialize')
 
     def __init__(
-            self, prompt:str, asking_for:str, converter:typing.Union[typing.Callable, commands.Converter],
-            emojis:typing.Optional[typing.List[discord.Emoji]]=None, serialize_function:typing.Callable[[typing.Any], typing.Any]=lambda x: x):
+            self, prompt: str, converter: typing.Union[typing.Callable, commands.Converter], asking_for: str = 'item',
+            emojis: typing.Optional[typing.List[discord.Emoji]] = None,
+            serialize_function: typing.Callable[[typing.Any], typing.Any] = lambda x: x):
         self.prompt = prompt
         self.asking_for = asking_for
         self.converter = converter
@@ -35,10 +36,10 @@ class SettingsMenuOption(object):
     __slots__ = ('context', '_display', 'converter_args', 'callback', 'emoji', 'allow_nullable',)
 
     def __init__(
-            self, ctx:commands.Context, display:typing.Union[str, typing.Callable[[commands.Context], str]],
-            converter_args:typing.List[SettingsMenuConverter]=None,
-            callback:typing.Callable[['SettingsMenuOption', typing.List[typing.Any]], None]=lambda x: None,
-            emoji:str=None, allow_nullable:bool=True):
+            self, ctx: commands.Context, display: typing.Union[str, typing.Callable[[commands.Context], str]],
+            converter_args: typing.List[SettingsMenuConverter] = None,
+            callback: typing.Callable[['SettingsMenuOption', typing.List[typing.Any]], None] = lambda x: None,
+            emoji: str = None, allow_nullable: bool = True):
         """
         Args:
             ctx (commands.Context): The context for which the menu is being invoked.
@@ -98,22 +99,26 @@ class SettingsMenuOption(object):
                 await called_data
 
     async def convert_prompted_information(
-            self, prompt:str, asking_for:str, converter:commands.Converter, reactions:typing.List[discord.Emoji]=None) -> typing.Any:
+            self, prompt: str, asking_for: str, converter: commands.Converter,
+            reactions: typing.List[discord.Emoji] = None) -> typing.Any:
         """
         Ask the user for some information, convert said information, and then return that converted value.
 
         Args:
-            prompt (str): The text that we sent to the user -- something along the lines of "what channel do you want to use" etc.
-            asking_for (str): Say what we're looking for them to send - doesn't need to be anything important, it just goes to the timeout message.
+            prompt (str): The text that we sent to the user -- something along the lines of "what
+                channel do you want to use" etc.
+            asking_for (str): Say what we're looking for them to send - doesn't need to be anything important,
+                it just goes to the timeout message.
             converter (commands.Converter): The converter used to work out what to change the given user value to.
-            reactions (typing.List[discord.Emoji], optional): The reactions that should be added to the prompt message. If provided then the content
-                of the added reaction is thrown into the converter instead.
+            reactions (typing.List[discord.Emoji], optional): The reactions that should be added to the prompt
+                message. If provided then the content of the added reaction is thrown into the converter instead.
 
         Returns:
             typing.Any: The converted information.
 
         Raises:
-            InvokedMetaCommand: If converting the information timed out, raise this error to signal to the menu that we should exit.
+            InvokedMetaCommand: If converting the information timed out, raise this error to signal to
+                the menu that we should exit.
             SettingsMenuError: If the converting failed for some other reason.
         """
 
@@ -172,7 +177,7 @@ class SettingsMenuOption(object):
         return value
 
     @classmethod
-    def get_guild_settings_mention(cls, ctx:commands.Context, attr:str, default:str='none') -> str:
+    def get_guild_settings_mention(cls, ctx: commands.Context, attr: str, default: str = 'none') -> str:
         """
         Get an item from the cached `Bot.guild_settings` object for the running guild and return
         either it's mention string, or the `default` arg.
@@ -190,7 +195,7 @@ class SettingsMenuOption(object):
         return cls.get_settings_mention(ctx, settings, attr, default)
 
     @classmethod
-    def get_user_settings_mention(cls, ctx:commands.Context, attr:str, default:str='none') -> str:
+    def get_user_settings_mention(cls, ctx: commands.Context, attr: str, default: str = 'none') -> str:
         """
         Get an item from the cached `Bot.user_settings` object for the running user and return
         either it's mention string, or the `default` arg.
@@ -208,7 +213,7 @@ class SettingsMenuOption(object):
         return cls.get_settings_mention(ctx, settings, attr, default)
 
     @classmethod
-    def get_settings_mention(cls, ctx:commands.Context, settings:dict, attr:str, default:str='none') -> str:
+    def get_settings_mention(cls, ctx: commands.Context, settings: dict, attr: str, default: str = 'none') -> str:
         """
         Get an item from the bot's settings.
 
@@ -239,7 +244,7 @@ class SettingsMenuOption(object):
         return cls.get_mention(data, default)
 
     @staticmethod
-    def get_mention(data:typing.Union[discord.abc.GuildChannel, discord.Role, None], default:str) -> str:
+    def get_mention(data: typing.Union[discord.abc.GuildChannel, discord.Role, None], default: str) -> str:
         """
         Get the mention of an object.
 
@@ -258,8 +263,8 @@ class SettingsMenuOption(object):
 
     @classmethod
     def get_set_guild_settings_callback(
-            cls, table_name:str, column_name:str,
-            serialize_function:typing.Callable[[typing.Any], typing.Any]=None) -> typing.Callable[[typing.Any], None]:
+            cls, table_name: str, column_name: str,
+            serialize_function: typing.Callable[[typing.Any], typing.Any] = None) -> typing.Callable[[typing.Any], None]:
         """
         Return an async method that takes the data given by `convert_prompted_information`, then
         saves it into the database - should be used in the SettingsMenu init.
@@ -267,10 +272,10 @@ class SettingsMenuOption(object):
         :meta private:
 
         Args:
-            table_name (str): The name of the table the data should be inserted into. This is not used when caching information.
-                This should NOT be a user supplied value.
-            column_name (str): The name of the column that the data should be inserted into. This is the same name that's used
-                for caching. This should NOT be a user supplied value.
+            table_name (str): The name of the table the data should be inserted into. This is
+                not used when caching information. This should NOT be a user supplied value.
+            column_name (str): The name of the column that the data should be inserted into.
+                This is the same name that's used for caching. This should NOT be a user supplied value.
             serialize_function (typing.Callable[[typing.Any], typing.Any], optional): The function that is called to convert the
                 input data in the callback into a database-friendly value. This is _not_ called for caching the value, only
                 for databasing. The default serialize function doesn't do anything, but is provided so you don't have to provide
@@ -286,8 +291,8 @@ class SettingsMenuOption(object):
 
     @classmethod
     def get_set_user_settings_callback(
-            cls, table_name:str, column_name:str,
-            serialize_function:typing.Callable[[typing.Any], typing.Any]=None) -> typing.Callable[[dict], None]:
+            cls, table_name: str, column_name: str,
+            serialize_function: typing.Callable[[typing.Any], typing.Any] = None) -> typing.Callable[[dict], None]:
         """
         Return an async method that takes the data given by `convert_prompted_information`, then
         saves it into the database - should be used in the SettingsMenu init.
@@ -313,8 +318,8 @@ class SettingsMenuOption(object):
 
     @staticmethod
     def get_set_settings_callback(
-            table_name:str, primary_key:str, column_name:str,
-            serialize_function:typing.Callable[[typing.Any], typing.Any]=None) -> typing.Callable[[dict], None]:
+            table_name: str, primary_key: str, column_name: str,
+            serialize_function: typing.Callable[[typing.Any], typing.Any] = None) -> typing.Callable[[dict], None]:
         """
         Return an async method that takes the data given by `convert_prompted_information`, then
         saves it into the database - should be used in the SettingsMenu init.
@@ -364,8 +369,8 @@ class SettingsMenuOption(object):
 
     @staticmethod
     def get_set_iterable_delete_callback(
-            table_name:str, column_name:str, cache_key:str,
-            database_key:str) -> typing.Callable[['SettingsMenu', commands.Context, int], None]:
+            table_name: str, column_name: str, cache_key: str,
+            database_key: str) -> typing.Callable[['SettingsMenu', commands.Context, int], None]:
         """
         Return an async method that takes the data retuend by `convert_prompted_information` and then
         saves it into the database - should be used for the SettingsMenu init.
@@ -380,7 +385,7 @@ class SettingsMenuOption(object):
             typing.Callable[['SettingsMenu', commands.Context, int], None]: A callable for `SettingsMenuIterable` objects to use.
         """
 
-        def wrapper(menu, ctx, delete_key:int):
+        def wrapper(menu, ctx, delete_key: int):
             """
             A sync wrapper so that we can return an async callback that deletes from the database.
             """
@@ -411,8 +416,8 @@ class SettingsMenuOption(object):
 
     @staticmethod
     def get_set_iterable_add_callback(
-            table_name:str, column_name:str, cache_key:str, database_key:str,
-            serialize_function:typing.Callable[[typing.Any], str]=None) -> typing.Callable[['SettingsMenu', commands.Context], None]:
+            table_name: str, column_name: str, cache_key: str, database_key: str,
+            serialize_function: typing.Callable[[typing.Any], str] = None) -> typing.Callable[['SettingsMenu', commands.Context], None]:
         """
         Return an async method that takes the data retuend by `convert_prompted_information` and then
         saves it into the database - should be used for the SettingsMenu init. This particular iterable
@@ -479,9 +484,67 @@ class SettingsMenuOption(object):
 
 class SettingsMenu(object):
     """
-    A settings menu object for setting up sub-menus or bot settings.
-    Each menu object must be added as its own command, with sub-menus being.
+    A settings menu object for setting up sub-menus or bot settings using reactions.
+    Each menu object must be added as its own command, with sub-menus being
     referred to by string in the MenuItem's action.
+
+    Examples:
+
+        ::
+
+            # We can pull out the settings menu mention method so that we can more easily refer to it in our lambdas.
+            settings_mention = voxelbotutils.SettingsMenuOption.get_guild_settings_mention
+
+            # Make an initial menu.
+            menu = voxelbotutils.SettingsMenu()
+
+            # And now we add some options.
+            menu.add_multiple_options(
+
+                # Every option that's added needs to be an instance of SettingsMenuOption.
+                voxelbotutils.SettingsMenuOption(
+
+                    # The first argument is the context, always.
+                    ctx=ctx,
+
+                    # Display is either a string, or a function that takes context as an argument to *return*
+                    # a string.
+                    display=lambda c: "Set quote channel (currently {0})".format(settings_mention(c, 'quote_channel_id')),
+
+                    # Converter args should be a list of SettingsMenuConverter options if present. These are the questions
+                    # asked to the user to get the relevant information out of them.
+                    converter_args=(
+                        voxelbotutils.SettingsMenuConverter(
+
+                            # Prompt is what's asked to the user
+                            prompt="What do you want to set the quote channel to?",
+
+                            # Converter is either a converter or a function that's run to convert the given argument.
+                            converter=commands.TextChannelConverter,
+                        ),
+                    ),
+
+                    # Callback is a function that's run with the converted information to store the data in a database
+                    # or otherwise.
+                    callback=voxelbotutils.SettingsMenuOption.get_set_guild_settings_callback('guild_settings', 'quote_channel_id'),
+                ),
+
+                # This is an option that calls a subcommand, also running some SettingsMenu code.
+                voxelbotutils.SettingsMenuOption(
+                    ctx=ctx,
+                    display="Set up VC max members",
+                    callback=self.bot.get_command("setup vcmaxmembers"),
+                ),
+            )
+
+            # And now we can run the menu
+            try:
+                await menu.start(ctx)
+                await ctx.send("Done setting up!")
+            except voxelbotutils.errors.InvokedMetaCommand:
+                pass
+
+
     """
 
     TICK_EMOJI = "\N{HEAVY CHECK MARK}"
@@ -491,39 +554,46 @@ class SettingsMenu(object):
         self.options: typing.List[SettingsMenuOption] = list()
         self.emoji_options: typing.Dict[str, SettingsMenuOption] = {}
 
-    def add_option(self, option:SettingsMenuOption):
+    def add_option(self, option: SettingsMenuOption):
         """
         Add an option to the settings list.
+
+        Args:
+            option (SettingsMenuOption): The option that you want to add to the menu.
         """
 
         self.options.append(option)
 
-    def add_multiple_options(self, *option:SettingsMenuOption):
+    def add_multiple_options(self, *option: SettingsMenuOption):
         """
         Add multiple options to the settings list at once.
+
+        Args:
+            *option (SettingsMenuOption): A list of options that you want to add to the menu.
         """
 
         self.options.extend(option)
 
-    def bulk_add_options(self, ctx:commands.Context, *args):
+    def bulk_add_options(self, ctx: commands.Context, *args):
         """
+        :meta private: (deprecated)
+
         Add multiple options to the settings list. Each option is simply thrown into a SettingsMenuOption item
         and then added to the options list.
-
-        :meta private:
         """
 
         for data in args:
             self.add_option(SettingsMenuOption(ctx, **data))
 
-    async def start(self, ctx:commands.Context, *, timeout:float=120, clear_reactions_on_loop:bool=False):
+    async def start(self, ctx: commands.Context, *, timeout: float = 120, clear_reactions_on_loop: bool = False):
         """
-        Start the menu running.
+        Starts the menu running.
 
         Args:
             ctx (commands.Context): The context object for the called command.
             timeout (float, optional): How long the bot should wait for a reaction.
-            clear_reactions_on_loop (bool, optional): Exactly as it says - when the menu loops, should reactions be cleared? You only need to set this to True if the items in a menu change on loop.
+            clear_reactions_on_loop (bool, optional): Exactly as it says - when the menu loops,
+                should reactions be cleared? You only need to set this to True if the items in a menu change on loop.
         """
 
         message = None
@@ -581,7 +651,7 @@ class SettingsMenu(object):
         except (discord.NotFound, discord.Forbidden, discord.HTTPException):
             pass
 
-    def get_sendable_data(self, ctx:commands.Context) -> typing.Tuple[dict, typing.List[str]]:
+    def get_sendable_data(self, ctx: commands.Context) -> typing.Tuple[dict, typing.List[str]]:
         """
         Get a valid set of sendable data for the destination.
 
@@ -589,7 +659,9 @@ class SettingsMenu(object):
             ctx (commands.Context): Just so we can set the invoke meta flag.
 
         Returns:
-            typing.Tuple[dict, typing.List[str]]: A tuple of the sendable data for the destination that can be unpacked into a `discord.abc.Messageable.send`, and a list of emoji to add to the message in question.
+            typing.Tuple[dict, typing.List[str]]: A tuple of the sendable data for the destination that
+                can be unpacked into a `discord.abc.Messageable.send`, and a list of emoji
+                to add to the message in question.
         """
 
         ctx.invoke_meta = True
@@ -624,23 +696,23 @@ class SettingsMenu(object):
 
 class SettingsMenuIterable(SettingsMenu):
     """
-    A version of the settings menu for dealing with things like lists and dictionaries
-    that are just straight read/stored in the database.
+    A version of the settings menu for dealing with things like lists and dictionaries.
     """
 
     def __init__(
-            self, table_name:str, column_name:str, cache_key:str, database_key:str,
-            key_display_function:typing.Callable[[typing.Any], str], value_display_function:typing.Callable[[typing.Any], str]=str,
-            converters:typing.List[SettingsMenuConverter]=None, *,
-            iterable_add_callback:typing.Callable[['SettingsMenu', commands.Context], None]=None,
-            iterable_delete_callback:typing.Callable[['SettingsMenu', commands.Context, int], None]=None):
+            self, table_name: str, column_name: str, cache_key: str, database_key: str,
+            key_display_function: typing.Callable[[typing.Any], str],
+            value_display_function: typing.Callable[[typing.Any], str] = str,
+            converters: typing.List[SettingsMenuConverter] = None, *,
+            iterable_add_callback: typing.Callable[['SettingsMenu', commands.Context], None] = None,
+            iterable_delete_callback: typing.Callable[['SettingsMenu', commands.Context, int], None] = None):
         """
         Args:
             table_name (str): The name of the table that the data should be inserted into.
             column_name (str): The column name for the table where the key should be inserted to.
             cache_key (str): The key that goes into `bot.guild_settings` to get to the cached iterable.
-            database_key (str): The key that would be inserted into the default `role_list` or `channel_list` tables. If you're not using this field
-                then this will probably be pretty useless to you.
+            database_key (str): The key that would be inserted into the default `role_list` or `channel_list`
+                tables. If you're not using this field then this will probably be pretty useless to you.
             key_display_function (typing.Callable[[typing.Any], str]): A function used to take the raw data from the key and
                 change it into a display value.
             value_display_function (typing.Callable[[typing.Any], str], optional): The function used to take the saved raw value
@@ -657,9 +729,6 @@ class SettingsMenuIterable(SettingsMenu):
                 If left blank then it defaults to making a new callback for you that just deletes from the `role_list` or `channel_list`
                 table as specified. These methods are only directly compatible with lists and dictionaries - nothing that requires multiple
                 arguments to be saved in a database; for those you will need to write your own method.
-
-        Raises:
-            ValueError: Description
         """
 
         try:
@@ -714,10 +783,7 @@ class SettingsMenuIterable(SettingsMenu):
         #     ]
         # ]
 
-    def get_sendable_data(self, ctx:commands.Context):
-        """
-        Create a list of mentions from the given guild settings key, creating all relevant callbacks.
-        """
+    def get_sendable_data(self, ctx: commands.Context):
 
         # Get the current data
         data_points = ctx.bot.guild_settings[ctx.guild.id][self.cache_key]
