@@ -13,7 +13,9 @@ from .cogs.utils.custom_bot import Bot
 
 
 # Set up the loggers
-def set_log_level(logger_to_change:typing.Union[logging.Logger, str], log_level:str, minimum_level:int=None) -> None:
+def set_log_level(
+        logger_to_change: typing.Union[logging.Logger, str], log_level: str,
+        minimum_level: int = None) -> None:
     """
     Set a logger to a default log level
 
@@ -54,7 +56,7 @@ logger = logging.getLogger('voxelbotutils')
 
 
 # Make sure the sharding info provided is correctish
-def validate_sharding_information(args:argparse.Namespace) -> typing.Optional[typing.List[int]]:
+def validate_sharding_information(args: argparse.Namespace) -> typing.Optional[typing.List[int]]:
     """
     Validate the given shard information and make sure that what's passed in is accurate
 
@@ -65,24 +67,28 @@ def validate_sharding_information(args:argparse.Namespace) -> typing.Optional[ty
         typing.List[int]: A list of shard IDs to use with the bot
     """
 
-    if args.shardcount is None:
-        return None
-    else:
-        if args.min is None and args.max is None:
-            args.min = 0
-            args.max = args.shardcount - 1
-        elif type(args.min) == int and type(args.max) == int:
-            pass
-        else:
-            logger.critical("You set a shardcount but not min/max shards")
-            exit(1)
+    # Set up some short vars for us to use
+    set_min_and_max = args.min is not None and args.max is not None
+    set_shardcount = args.shardcount is not None
+
+    # If we haven't said anything, assume one shard
+    if not set_shardcount and not set_min_and_max:
+        args.shardcount = 1
+        return [0]
+
+    # If we haven't set a min or max but we HAVE set a shardcount,
+    # then assume we're using all shards
+    if set_shardcount and not set_min_and_max:
+        args.min = 0
+        args.max = args.shardcount - 1
+
+    # If we gave a min and max but no shardcount, that's just invalid
+    if set_min_and_max and not set_shardcount:
+        logger.critical("You set a min/max shard amount but no shard count")
+        exit(1)
+
+    # Work out the shard IDs to launch with
     shard_ids = list(range(args.min, args.max + 1))
-    if args.shardcount is None and (args.min or args.max):
-        logger.critical("You set a min/max shard handler but no shard count")
-        exit(1)
-    if args.shardcount is not None and not (args.min is not None and args.max is not None):
-        logger.critical("You set a shardcount but not min/max shards")
-        exit(1)
     return shard_ids
 
 
@@ -97,7 +103,7 @@ class LogFilter(logging.Filter):
     # https://stackoverflow.com/a/28743317/2224197
     # http://stackoverflow.com/a/24956305/408556
 
-    def __init__(self, filter_level:int):
+    def __init__(self, filter_level: int):
         self.filter_level = filter_level
 
     def filter(self, record):
@@ -106,7 +112,7 @@ class LogFilter(logging.Filter):
         return record.levelno < self.filter_level
 
 
-def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
+def set_default_log_levels(bot: Bot, args: argparse.Namespace) -> None:
     """
     Set the default levels for the logger
 
@@ -238,7 +244,7 @@ async def create_initial_database(db) -> None:
     return True
 
 
-async def start_database_pool(config:dict) -> None:
+async def start_database_pool(config: dict) -> None:
     """
     Start the database pool connection
     """
@@ -250,7 +256,10 @@ async def start_database_pool(config:dict) -> None:
     except KeyError:
         raise Exception("KeyError creating database pool - is there a 'database' object in the config?")
     except ConnectionRefusedError:
-        raise Exception("ConnectionRefusedError creating database pool - did you set the right information in the config, and is the database running?")
+        raise Exception(
+            "ConnectionRefusedError creating database pool - did you set the right "
+            "information in the config, and is the database running?"
+        )
     except Exception:
         raise Exception("Error creating database pool")
     logger.info("Created database pool successfully")
@@ -271,13 +280,16 @@ async def start_redis_pool(config:dict) -> None:
     except KeyError:
         raise KeyError("KeyError creating redis pool - is there a 'redis' object in the config?")
     except ConnectionRefusedError:
-        raise ConnectionRefusedError("ConnectionRefusedError creating redis pool - did you set the right information in the config, and is the database running?")
+        raise ConnectionRefusedError(
+            "ConnectionRefusedError creating redis pool - did you set the right "
+            "information in the config, and is the database running?"
+        )
     except Exception:
         raise Exception("Error creating redis pool")
     logger.info("Created redis pool successfully")
 
 
-def run_bot(args:argparse.Namespace) -> None:
+def run_bot(args: argparse.Namespace) -> None:
     """
     Starts the bot, connects the database, runs the async loop forever
 
@@ -341,7 +353,7 @@ def run_bot(args:argparse.Namespace) -> None:
     loop.close()
 
 
-def run_website(args:argparse.Namespace) -> None:
+def run_website(args: argparse.Namespace) -> None:
     """
     Starts the website, connects the database, logs in the specified bots, runs the async loop forever
 
@@ -395,14 +407,19 @@ def run_website(args:argparse.Namespace) -> None:
     # Add our jinja env filters
     def regex_replace(string, find, replace):
         return re.sub(find, replace, string, re.IGNORECASE | re.MULTILINE)
+
     def escape_text(string):
         return html.escape(string)
+
     def timestamp(string):
         return dt.fromtimestamp(float(string))
+
     def int_to_hex(string):
         return format(hex(int(string))[2:], "0>6")
+
     def to_markdown(string):
         return markdown.markdown(string, extensions=['extra'])
+
     def display_mentions(string, users):
         def get_display_name(group):
             user = users.get(group.group('userid'))
