@@ -1,6 +1,6 @@
 from .utils.add_discord_arguments import add_discord_arguments
 from .utils.get_avatar_url import get_avatar_url
-from .utils.requires_login import requires_login
+from .utils.requires_login import is_logged_in, requires_login
 from .utils.process_discord_login import (
     get_discord_login_url, process_discord_login, get_user_info_from_session, get_access_token_from_session,
     get_user_guilds_from_session, add_user_to_guild_from_session,
